@@ -40,10 +40,9 @@ def writeChannels(chanInfo, bak=backUpVals):
             else:
                 curVals['channels'][ch][key] = chanInfo['channels'][ch][key]
     if all([set(curVals['channels']) != set(ele['value']['channels'])
-            for ele in bak if ele['type'] == 'group']):
-        bak += [{'type': 'group', 'value': curVals, 'name': 'group'}]
-
-
+            for ele in bak.items() if ele['type'] == 'group']):
+        name = 'group_of|' + '|'.join(list(curVals['channels'].keys()))
+        bak[name] = [{'type': 'group', 'value': curVals, 'sno': len(bak)}]
 
     rampYourself = True
     if 'tramp' in chanInfo:
