@@ -13,10 +13,10 @@ def writeMatrix(basename, inpMat, firstRow=1, firstCol=1, suffix=None,
     curMat = readMatrix(basename=basename, rows=inpMat.shape[0],
                         cols=inpMat.shape[1], firstRow=firstRow,
                         firstCol=firstCol, suffix=suffix)
-    if all([ele['name'] != basename for ele in bak]):
-        bak += [{'type': 'matrix', 'name': basename, 'suffix': suffix,
-                 'value': curMat, 'firstRow': firstRow, 'firstCol': firstCol,
-                 'tramp': tramp}]
+    if basename not in bak:
+        bak[basename] = {'type': 'matrix', 'name': basename, 'suffix': suffix,
+                         'value': curMat, 'firstRow': firstRow,
+                         'firstCol': firstCol,'tramp': tramp, 'sno': len(bak)}
     # Special case, changing filter gains, can use TRAMP
     rampYourself = True
     if suffix == 'GAIN':
